@@ -17,6 +17,10 @@ FakeDatetime.__name__ = 'datetime.datetime'
 
 def load_tests(loader, tests, pattern):
 
+    # Since tzset does not work under Windows, just give up.
+    if os.name == 'nt':
+        return unittest.TestSuite(tests)
+
     # Force time zone to EST/EDT to make localtime tests work.
     os.environ['TZ'] = 'EST+05EDT,M4.1.0,M10.5.0'
     time.tzset()
@@ -28,7 +32,7 @@ def load_tests(loader, tests, pattern):
 
     datetime.datetime = FakeDatetime
 
-    if sys.version_info >= (2, 7):
+    if sys.version_info >= (3, 9):
         tests.extend([
             doctest.DocFileSuite('../doc/%s' % os.path.basename(path))
             for path in glob(os.path.dirname(__file__) + '/../doc/*.rst')
